pub fn plan_annotation_plane(
bytes: &[u8],
request: &AnnotationPlaneRequest,
) -> Result<AnnotationPlanePlan, String>Expand description
Create one bounded textured annotation through the shared native product planner.
pub fn plan_annotation_plane(
bytes: &[u8],
request: &AnnotationPlaneRequest,
) -> Result<AnnotationPlanePlan, String>Create one bounded textured annotation through the shared native product planner.