process_geometry_streaming_with_options_and_bootstrap

Function process_geometry_streaming_with_options_and_bootstrap 

pub fn process_geometry_streaming_with_options_and_bootstrap(
    content: &[u8],
    options: StreamingOptions,
    on_batch: impl FnMut(&[MeshData], usize, usize),
    on_color_update: impl FnMut(&[(u32, [f32; 4])]),
    on_quick_metadata_bootstrap: impl FnMut(&QuickMetadataBootstrap),
) -> ProcessingResult
Process IFC content with parallel geometry extraction and emit a quick metadata bootstrap once the scan phase completes.